<?php
/**
 * Journey section
 *
 * This is the template for the content of journey section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_journey_section' ) ) :
    /**
    * Add journey section
    *
    *@since Personify 0.1
    */
    function personify_add_journey_section() {
        // Check if journey is enabled on frontpage
        $journey_enable = apply_filters( 'personify_section_status', true, 'journey_section_enable' );

        if ( true !== $journey_enable ) {
            return false;
        }
        // Get journey section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_journey_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render journey section now.
        personify_render_journey_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_journey_section', 60 );


if ( ! function_exists( 'personify_get_journey_section_details' ) ) :
    /**
    * journey section details.
    *
    * @since Personify 0.1
    * @param array $input journey section details.
    */
    function personify_get_journey_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();

        $page_id = ! empty( $options['journey_content_page'] ) ? $options['journey_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['image']     = get_the_post_thumbnail_url( '', 'large' );
                $page_post['excerpt']   = wpautop( personify_trim_content( 70 ) );
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();


        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// journey section content details.
add_filter( 'personify_filter_journey_section_details', 'personify_get_journey_section_details' );


if ( ! function_exists( 'personify_render_journey_section' ) ) :
  /**
   * Start journey section
   *
   * @return string journey content
   * @since Personify 0.1
   *
   */
   function personify_render_journey_section( $content_details = array() ) {
        $options = personify_get_theme_options();
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'personify' );
        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="journey" class="relative">
                <div class="wrapper">
                    <div class="section-content clear">
                        <div class="journey-description">
                            <article class="hentry <?php echo ( ! empty( $content['image'] ) ) ? 'has-post-thumbnail' : 'no-post-thumbnail'; ?>">
                                <div class="entry-container">

                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </header>

                                    <div class="entry-content">
                                        <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->

                                    <span class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $read_more ); ?></a>
                                    </span><!--- .read-more -->
                                </div><!-- .entry-container -->

                                <?php if ( ! empty( $content['image'] ) ) : ?>
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    </div><!-- .featured-image -->
                                <?php endif; ?>
                            </article>
                        </div><!-- .journey-description -->
                    </div><!-- .section-content -->  
                </div><!-- .wrapper -->
            </div><!-- #journey -->
        <?php endforeach;
    }
endif;