<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

get_header();

/**
 * personify_simple_breadcrumb_action hook
 *
 * @hooked personify_add_breadcrumb -  10
 *
 */
do_action( 'personify_simple_breadcrumb_action' ); 
?>

<div id="page-title" class="relative">
    <div class="wrapper">
        <header class="page-header">
        	<?php 
        	$blog_page = ( is_home() && ! is_front_page() ) ? single_post_title( '', false ) : esc_html__( 'Blogs', 'personify' );
        	?>
			<h2 class="entry-title"><?php echo esc_html( $blog_page ); ?></h2>
			
        </header>
    </div><!-- .wrapper -->
</div><!-- #page-title -->

<div class="wrapper page-section no-padding-top">       
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
			<div class="blog-posts-wrapper">
				<?php
				if ( have_posts() ) : 
					$i = 1;
					$int = 0;
					/* Start the Loop */
					while ( have_posts() ) : the_post();
						if ( has_post_thumbnail() ) {
							$int = 0;
						}

						/**
						* Hook - personify_get_content_action.
						*
						* @hooked personify_get_content 
						*/
						do_action( 'personify_get_content_action', $i, $int );

						$i++;
						$int++;
					endwhile;

				else :

					get_template_part( 'template-parts/content', 'none' );

				endif; 
				?>
			</div><!-- .blog-posts-wrapper -->
			<?php
			/**
			* Hook - personify_action_pagination.
			*
			* @hooked personify_pagination 
			*/
			do_action( 'personify_action_pagination' ); 

			/**
			* Hook - personify_infinite_loader_spinner_action.
			*
			* @hooked personify_infinite_loader_spinner 
			*/
			do_action( 'personify_infinite_loader_spinner_action' );
			?>
		</main><!-- #main -->
	</div><!-- #primary -->
</div><!-- .wrapper -->
<?php
get_footer();
